@@ -3,12 +3,13 @@
 #
 #  (C) Paul Evans, 2023 -- leonerd@leonerd.org.uk
 
-package XS::Parse::Keyword::FromPerl 0.08;
+package XS::Parse::Keyword::FromPerl 0.09;
 
 use v5.26; # XS code needs op_class() and the OPclass_* constants
 use warnings;
 
-use meta 0.003;
+use meta 0.003_002;
+no warnings 'meta::experimental';
 
 require XSLoader;
 XSLoader::load( __PACKAGE__, our $VERSION );
